@@ -2,6 +2,7 @@
 #'
 #' @param subskin numeric
 #' @param age_in_days integer, the age in days.
+#' @param age_in_months numeric, the age in months.
 #' @param sex integer, the sex where 1 is male and 2 is female
 #' @param flag_threshold numeric, a length 1 threshold. If the absolute value of the z-score is greater than
 #'        this parameter, the z-score gets flagged in the resulting data frame.
@@ -10,10 +11,16 @@
 #' @include z-score-helper.R
 #' @noRd
 anthro_zscore_subscapular_skinfold_for_age <-
-  function(subskin, age_in_days, sex, flag_threshold = 5,
-             growthstandards = growthstandards_ssanthro) {
-    anthro_zscore_adjusted("ss", subskin, age_in_days, sex,
-      growthstandards, flag_threshold,
+  function(subskin, age_in_days, age_in_months, sex, flag_threshold = 5,
+           growthstandards = growthstandards_ssanthro) {
+    anthro_zscore_adjusted(
+      name = "ss",
+      measure = subskin,
+      age_in_days = age_in_days,
+      age_in_months = age_in_months,
+      sex = sex,
+      growthstandards = growthstandards,
+      flag_threshold = flag_threshold,
       allowed_age_range = c(91, 1856)
     )
   }
